package com.example.dsosnowski.vechicle_v1;

import android.app.Activity;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

import java.util.Set;

//------------------------------------------------------------------
public class DeviceActivity extends Activity {

    //Declarations
    TextView textInfo;
    ListView listDevice;

    //EXTRA STRINGS to send to next activity
    public static String EXTRA_DEVICE_ADDRESS = "device_address";
    public static String EXTRA_DEVICE_NAME = "device_name";

    //bluetooth
    private BluetoothAdapter myBluetooth;
    private Set<BluetoothDevice> pairedDevices;

    //list
    private ArrayAdapter<String> myPairedDevicesArrayAdapter;


    //------------------------------------------------------------------
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_device);
    }

    //------------------------------------------------------------------
    @Override
    public void onResume(){
        super.onResume();

        textInfo = (TextView) findViewById(R.id.id_device_info);
        listDevice = (ListView) findViewById(R.id.id_device_list);

        textInfo.setText("Wybierz urządzenie");

        myPairedDevicesArrayAdapter = new ArrayAdapter<String>(this, R.layout.device_name);
        listDevice.setAdapter(myPairedDevicesArrayAdapter);
        listDevice.setOnItemClickListener(myDeviceClickListener);

        //get bluetooth
        myBluetooth = BluetoothAdapter.getDefaultAdapter();
        checkBluetoothEnable();

        //list of paried devices
        pairedDevices = myBluetooth.getBondedDevices();

        //add previosuly paired devices to the array
        if (pairedDevices.size() > 0) {
            for (BluetoothDevice device : pairedDevices) {
                myPairedDevicesArrayAdapter.add(device.getName() + "\n" + device.getAddress());
            }
        } else {
            // String noDevices = "Brak sparowanych urządzeń";
            // myPairedDevicesArrayAdapter.add(noDevices);
            Toast.makeText(getApplicationContext(), "brak sparowanych urządzeń...", Toast.LENGTH_SHORT).show();
        }

    }

    //------------------------------------------------------------------
    private AdapterView.OnItemClickListener myDeviceClickListener = new AdapterView.OnItemClickListener() {
        @Override
        public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
            //Toast.makeText(getApplicationContext(), "Nawiązywanie połączenia...", Toast.LENGTH_SHORT).show();
            Toast.makeText(getBaseContext(), "Nawiązywanie połączenia...", Toast.LENGTH_SHORT).show();

            // Get the device MAC address, which is the last 17 chars in the View
            String info = ((TextView) view).getText().toString();
            int charPos = info.indexOf("\n", 0) + 1;

            String name = info.substring(0, charPos);
            String address = info.substring(info.length() - 17);

            // Make an intent to start next activity while taking an extra which is the MAC address.
            Intent myIntent = new Intent(getApplicationContext(), MainActivity.class);
            myIntent.putExtra(EXTRA_DEVICE_ADDRESS, address);
            myIntent.putExtra(EXTRA_DEVICE_NAME, name);
            startActivity(myIntent);
        }
    };

    //------------------------------------------------------------------
    private void checkBluetoothEnable() {
        if(myBluetooth == null) {
            Toast.makeText(getApplicationContext(), "Brak modułu Bluetooth", Toast.LENGTH_SHORT).show();
        } else {
            if (!myBluetooth.isEnabled()) {
                Intent intentBluetoothEnable = new Intent(BluetoothAdapter.ACTION_REQUEST_ENABLE);
                startActivityForResult(intentBluetoothEnable, 1);
                myBluetooth = BluetoothAdapter.getDefaultAdapter();
            }
        }
    }
}
