package com.example.dsosnowski.vechicle_v1;
import android.app.Activity;
import android.content.Context;
import android.content.pm.ActivityInfo;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;


import android.os.Bundle;
import java.io.IOException;
import java.util.UUID;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothSocket;
import android.content.Intent;
import android.os.Handler;
import android.view.MotionEvent;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;
import android.widget.EditText;
import android.widget.Toast;

public class MainActivity extends Activity implements SensorEventListener {
    private SensorManager mSensorManager;
    private Sensor mAccelerometer;

    Button btnReset, btnGo;
    TextView textTitle, textSensor1, textSensor2, textSensor3, textCommand;
    Handler bluetoothIn;

    final int handlerState = 0;        				 //used to identify handler message
    private BluetoothAdapter btAdapter = null;
    private BluetoothSocket btSocket = null;
    private StringBuilder recDataString = new StringBuilder();

    //private ConnectedThread mConnectedThread;

    // SPP UUID service - this should work for most devices
    private static final UUID BTMODULEUUID = UUID.fromString("00001101-0000-1000-8000-00805F9B34FB");


    public static final int DEVICE_ACTIVITY_REQUEST_CODE = 1;
    public static final int MAIN_ACTIVITY_REQUEST_CODE = 2;
    //public static final int NAME_ACTIVITY_REQUEST_CODE = 3;

    int sensivity = 20;
    int period = 3;
    int sensor_period;
    int max_val = 99;
    int zero_range = 10;
    int mode;
    String command;

    float floatx;
    float floaty;
    float floatz;
    int offx;
    int offy;
    int offz;
    int ix;
    int iy;
    int iz;


    //---------------------------------------------------------------------------------------------
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);

        mSensorManager = (SensorManager) getSystemService(Context.SENSOR_SERVICE);
        mAccelerometer = mSensorManager.getDefaultSensor(Sensor.TYPE_ACCELEROMETER);

        //Link the buttons and textViews to respective views
        btnReset = (Button) findViewById(R.id.buttonReset);
        btnGo = (Button) findViewById(R.id.buttonGo);

        textTitle = (TextView) findViewById(R.id.id_title);
        textSensor1 = (TextView) findViewById(R.id.id_sensor1);
        textSensor2 = (TextView) findViewById(R.id.id_sensor2);
        textSensor3 = (TextView) findViewById(R.id.id_sensor3);
        textCommand = (TextView) findViewById(R.id.id_command);

        //------------------------------------------------------------------------------
        btAdapter = BluetoothAdapter.getDefaultAdapter();       // get Bluetooth adapter
        checkBTState();

        //------------------------------------------------------------------------------
        btnReset.setOnClickListener(new OnClickListener() {
            public void onClick(View v) {
                offx = ix;
                offy = iy;
                offz = iz;
                Toast.makeText(getBaseContext(), "Reset param", Toast.LENGTH_SHORT).show();
            }
        });

        //------------------------------------------------------------------------------
        btnGo.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                if (event.getAction() == MotionEvent.ACTION_DOWN) mode = 1;
                if (event.getAction() == MotionEvent.ACTION_UP) mode = 0;
                return false;
            }
        });


    }

    //---------------------------------------------------------------------------------------------
    @Override
    public final void onAccuracyChanged(Sensor sensor, int accuracy)
    {
        // Do something here if sensor accuracy changes.
    }

    @Override
    public final void onSensorChanged(SensorEvent event)
    {
        sensor_period++;
       if (sensor_period > 2) {

           sensor_period = 0;
           floatx = event.values[0];
           floaty = event.values[1];
           floatz = event.values[2];
           ix = (int) (floatx * sensivity);
           iy = (int) (floaty * sensivity);
           iz = (int) (floatz * (sensivity + 10));

           int val;
           val = (ix - offx);
           if ((val > -(zero_range)) && (val < zero_range)) val = 0;
           if (val < -(max_val)) val = -(max_val);
           if (val > max_val) val = max_val;
           textSensor1.setText("X=  " + val);

           val = (iy - offy);
           if ((val > -(zero_range)) && (val < zero_range)) val = 0;
           if (val < -(max_val)) val = -(max_val);
           if (val > max_val) val = max_val;
           textSensor2.setText("Y=  " + val);

           command = "\nx";
           command += val;

           val = (iz - offz);
           if ((val > -(zero_range)) && (val < zero_range)) val = 0;
           if (val < -(max_val)) val = -(max_val);
           if (val > max_val) val = max_val;
           textSensor3.setText("Z=  " + val);

           command += ",";
           command += val;
           command += "\n";

           if (mode == 1) {
               textTitle.setText("   GO!!!   ");
               textCommand.setText(command);
           } else {
               textTitle.setText("   Stop    ");
               command = "\nx0,0\n";
               textCommand.setText(command);
           }

           if (btSocket != null) {
               try {
                   btSocket.getOutputStream().write(command.toString().getBytes());
               } catch (IOException e) {
               }
           }
       }
    }

    //---------------------------------------------------------------------------------------------
    private BluetoothSocket createBluetoothSocket(BluetoothDevice device) throws IOException {

        return  device.createRfcommSocketToServiceRecord(BTMODULEUUID);
        //creates secure outgoing connecetion with BT device using UUID
    }


    //---------------------------------------------------------------------------------------------
    @Override
    public void onResume() {
        super.onResume();

        mSensorManager.registerListener(this, mAccelerometer, SensorManager.SENSOR_DELAY_UI);


        //Get MAC address from DeviceListActivity via intent
        Intent intent = getIntent();

        //Get the MAC address from the DeviceListActivty via EXTRA
        String address = intent.getStringExtra(DeviceActivity.EXTRA_DEVICE_ADDRESS);
        String name = intent.getStringExtra(DeviceActivity.EXTRA_DEVICE_NAME);

        //create device and set the MAC address
        BluetoothDevice device = btAdapter.getRemoteDevice(address);

        try {
            btSocket = createBluetoothSocket(device);
        } catch (IOException e) {
            Toast.makeText(getBaseContext(), "Socket creation failed", Toast.LENGTH_LONG).show();
        }
        // Establish the Bluetooth socket connection.
        try
        {
            btSocket.connect();
        } catch (IOException e) {
            try
            {
                btSocket.close();
            } catch (IOException e2)
            {
                //insert code to deal with this
            }
        }
        //mConnectedThread = new ConnectedThread(btSocket);
        //mConnectedThread.start();
    }

    @Override
    public void onPause()
    {
        super.onPause();
        mSensorManager.unregisterListener(this);

        try
        {
            //Don't leave Bluetooth sockets open when leaving activity
            btSocket.close();
        } catch (IOException e2) {
            //insert code to deal with this
        }
    }

    //Checks that the Android device Bluetooth is available and prompts to be turned on if off
    private void checkBTState() {

        if(btAdapter==null) {
            Toast.makeText(getBaseContext(), "Device does not support bluetooth", Toast.LENGTH_LONG).show();
        } else {
            if (btAdapter.isEnabled()) {
            } else {
                Intent enableBtIntent = new Intent(BluetoothAdapter.ACTION_REQUEST_ENABLE);
                startActivityForResult(enableBtIntent, 1);
            }
        }
    }

    //create new class for connect thread
    /*private class ConnectedThread extends Thread {
        private final InputStream mmInStream;
        private final OutputStream mmOutStream;

        //creation of the connect thread
        public ConnectedThread(BluetoothSocket socket) {
            InputStream tmpIn = null;
            OutputStream tmpOut = null;

            try {
                //Create I/O streams for connection
                tmpIn = socket.getInputStream();
                tmpOut = socket.getOutputStream();
            } catch (IOException e) { }

            mmInStream = tmpIn;
            mmOutStream = tmpOut;
        }


        public void run() {
            byte[] buffer = new byte[256];
            int bytes;

            // Keep looping to listen for received messages
            while (true) {
                try {
                    bytes = mmInStream.read(buffer);        	//read bytes from input buffer
                    String readMessage = new String(buffer, 0, bytes);
                    // Send the obtained bytes to the UI Activity via handler
                    bluetoothIn.obtainMessage(handlerState, bytes, -1, readMessage).sendToTarget();
                } catch (IOException e) {
                    break;
                }
            }
        }
        //write method
        public void write(String input) {
            byte[] msgBuffer = input.getBytes();           //converts entered String into bytes
            try {
                mmOutStream.write(msgBuffer);                //write bytes over BT connection via outstream
            } catch (IOException e) {
                //if you cannot write, close the application
                Toast.makeText(getBaseContext(), "Connection Failure", Toast.LENGTH_LONG).show();
                finish();

            }
        }
    }*/
}
